Module pkg

Module pkg 

Structs

Package
A package is a tar archive version of the .webc/proj directory of a project. Packages come with a config JSON file in the first few bytes
PackageConfig
PackageManager
The package manager manages project packages. Packages are installed to ~/.webc/pkgs, and can be accessed from webcomposer scripts via @pkgs/{name}-{version}.

Functions

webc_home
webc_pkgs_dir