Structs
- Package
- A package is a tar archive version of the
.webc/projdirectory of a project. Packages come with a config JSON file in the first few bytes - Package
Config - Package
Manager - The package manager manages project packages. Packages are installed to
~/.webc/pkgs, and can be accessed from webcomposer scripts via@pkgs/{name}-{version}.